@@ -11,13 +11,18 @@ from .cifar10.model_vgg import vgg_cifar10, vgg_cifar10_pretrained
 from .imagenet.model_mobilenet import (mobilenet_imagenet,
                                        mobilenet_imagenet_pretrained,
                                        mobilenet_cats_vs_dogs_pretrained,
-                                       mobilenet_imagenette_pretrained)
+                                       mobilenet_imagenette_pretrained,
+                                       mobilenet_faceidentification_pretrained,
+                                       mobilenet_faceverification_pretrained)
 from .imagenet.model_vgg import (vgg_imagenet, vgg_imagenet_pretrained,
                                  vgg_melanoma_pretrained, vgg_odir5k_pretrained,
-                                 vgg_retinal_oct_pretrained)
+                                 vgg_retinal_oct_pretrained, vgg_ecg_pretrained)
 from .imagenet.model_mobilenet_edge import (mobilenet_edge_imagenet,
                                             mobilenet_edge_imagenet_pretrained)
 from .kws.model_ds_cnn import ds_cnn_kws, ds_cnn_kws_pretrained
+from .modelnet40.model_pointnet_plus import (pointnet_plus_modelnet40,
+                                             pointnet_plus_modelnet40_pretrained
+                                            )
 from .utk_face.model_vgg import vgg_utk_face, vgg_utk_face_pretrained
 from .cse2018.model_tse import tse_mlp_cse2018, tse_mlp_cse2018_pretrained
 from .tabular_data import tabular_data
@@ -25,3 +30,6 @@ from .detection.model_yolo import (yolo_base, yolo_widerface_pretrained,
                                    yolo_voc_pretrained)
 from .cwru.model_convtiny import convtiny_cwru, convtiny_cwru_pretrained
 from .gamma_constraint import add_gamma_constraint
+from .filter_pruning import delete_filters, prune_model
+
+from .mnist.model_gxnor import gxnor_mnist, gxnor_mnist_pretrained
