@@ -169,12 +169,11 @@ class BatchGenerator(Sequence):
 
                         shifted_box = BoundingBox(0, 0, center_w, center_h)
 
-                        for i in range(len(self._anchors)):
-                            anchor = self._anchors[i]
+                        for anchor_id, anchor in enumerate(self._anchors):
                             iou = shifted_box.iou(anchor)
 
                             if max_iou < iou:
-                                best_anchor = i
+                                best_anchor = anchor_id
                                 max_iou = iou
 
                         # assign ground truth x, y, w, h, confidence and class
