@@ -260,7 +260,7 @@ def parse_voc_annotations(gt_folder, image_folder, file_path, labels):
             list: list of file names
         """
         file_list = []
-        with open(file_path, "r") as f:
+        with open(file_path, "r", encoding='UTF-8') as f:
             for line in f:
                 file_list.append(line.rstrip())
         return file_list
@@ -344,7 +344,7 @@ def parse_widerface_annotations(gt_file, image_folder):
 
     all_data = []
 
-    with open(gt_file, "r") as f:
+    with open(gt_file, "r", encoding='UTF-8') as f:
         for line in f:
             file_path = line.rstrip()
             full_file_path = os.path.join(image_folder, str(file_path))
