@@ -270,7 +270,7 @@ def get_gesture_data(dataset_name, datafile, labelfile=None):
     data = None
     if os.path.isfile(datafile):
         if dataset_name == "dvs_gesture":
-            with open(labelfile) as f:
+            with open(labelfile, encoding='UTF-8') as f:
                 # Get class labels and start/stop times from the labels.csv file
                 trial_times = [line.split(',') for line in f]
 
@@ -397,4 +397,5 @@ def download_and_extract_dataset(data_url, dest_directory):
         print()
         statinfo = os.stat(filepath)
         print(f"Successfully downloaded {filename} ({statinfo.st_size} bytes)")
-    tarfile.open(filepath, 'r:gz').extractall(dest_directory)
+    with tarfile.open(filepath, 'r:gz') as tar:
+        tar.extractall(dest_directory)
