@@ -29,15 +29,12 @@ compatible for Akida with:
 
 import warnings
 
-# Tensorflow/Keras Imports
 from tensorflow.keras import Model, regularizers
 from tensorflow.keras.utils import get_file
 from tensorflow.keras.layers import Input, Reshape, Dropout, Activation
 
-# cnn2snn Imports
 from cnn2snn import load_quantized_model, quantize
 
-# Local utils
 from ..layer_blocks import conv_block, separable_conv_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/mobilenet/'
@@ -453,3 +450,40 @@ def mobilenet_imagenette_pretrained(alpha=1.0):
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
+
+
+def mobilenet_faceidentification_pretrained():
+    """
+    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
+    CASIA Webface dataset and that performs face identification.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'mobilenet_faceidentification_iq8_wq4_aq4.h5'
+    file_hash = 'fdc05362e0afd5e01634b9630ecfd461fa84070c484c5e4d90c48fa3a388b895'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
+
+
+def mobilenet_faceverification_pretrained():
+    """
+    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
+    CASIA Webface dataset and optimized with ArcFace that can perform face
+    verification on LFW.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'mobilenet_faceverification_iq8_wq4_aq4.h5'
+    file_hash = '663a1c94426936eaa897701cab267ba4a60b6fd2224ee72353e48d976302dc9b'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
