@@ -281,3 +281,21 @@ def vgg_retinal_oct_pretrained():
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
+
+
+def vgg_ecg_pretrained():
+    """
+    Helper method to retrieve a `vgg_imagenet` model that was trained on ECG
+    classification Physionet2017 dataset.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'vgg11_ecg_iq8_wq4_aq4.h5'
+    file_hash = '5a7ac2acc298fc599c412dd8c59ca7d0d6f1ce68a96ac56af7e2b293a4b52f4b'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
