@@ -18,32 +18,28 @@
 KWS model training script.
 """
 
-# System imports
 import os
-import argparse
 import pickle
 
-# Keras imports
-from tensorflow.keras.optimizers import Adam
 from tensorflow.keras.utils import to_categorical, get_file
 
-# Akida
 from cnn2snn import load_quantized_model, quantize_layer
 
-# Better LR Handling
-from akida_models.cyclic_lr import CyclicLR
+from ..cyclic_lr import CyclicLR
+from ..training import get_training_parser, compile_model, evaluate_model
 
 
-def get_rescaled_dataset(a, b):
-    """ Loads and rescales KWS dataset.
-
-    Args:
-        a (int): rescale factor
-        b (int): rescale bias
+def get_data():
+    """ Loads KWS data.
 
     Returns:
         tuple: train data, train labels, validation data and validation labels
     """
+    # Input scaling: Akida is configured to take 8-bit inputs without rescaling
+    # but for the training, we use float weights between 0 and 1
+    a = 255
+    b = 0
+
     # Load pre-processed dataset
     fname = get_file(
         fname='kws_preprocessed_all_words_except_backward_follow_forward.pkl',
@@ -64,29 +60,11 @@ def get_rescaled_dataset(a, b):
     return x_train_keras, y_train, x_val_keras, y_val
 
 
-def compile_model(model, learning_rate=1e-4):
-    """ Compiles the model.
-
-    Args:
-        model (tf.Keras.Model): the model to compile
-        learning_rate (float): the learning rate
-
-    Returns:
-        tf.Keras.Model: the compiled model
-    """
-    # Initialize optimizer and compile model
-    opt = Adam(lr=learning_rate)
-    model.compile(loss='categorical_crossentropy',
-                  optimizer=opt,
-                  metrics=['accuracy'])
-    return model
-
-
 def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
     """ Trains the model.
 
     Args:
-         model (tf.Keras.Model): the model to train
+         model (tf.keras.Model): the model to train
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
         x_val (numpy.ndarray): validation data
@@ -112,99 +90,57 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
                    mode='triangular')
     callbacks.append(clr)
 
-    # Compile model
-    model = compile_model(model, max_lr)
-
-    model.fit(x_train,
-              to_categorical(y_train),
-              batch_size=batch_size,
-              epochs=epochs,
-              verbose=1,
-              validation_data=(x_val, to_categorical(y_val)),
-              callbacks=callbacks)
-
-
-def evaluate_model(model, x_val, y_val):
-    """ Evaluates model performances.
-
-    Args:
-        model (tf.Keras.Model): the model to evaluate
-        x_val (numpy.ndarray): evaluation data
-        y_val (numpy.ndarray): evaluation labels
-    """
-    model = compile_model(model)
-    _, accuracy = model.evaluate(x_val, to_categorical(y_val), verbose=0)
-    print('Validation accuracy:', accuracy)
+    history = model.fit(x_train,
+                        to_categorical(y_train),
+                        batch_size=batch_size,
+                        epochs=epochs,
+                        verbose=1,
+                        validation_data=(x_val, to_categorical(y_val)),
+                        callbacks=callbacks)
+    print(history.history)
 
 
 def main():
     """ Entry point for script and CLI usage.
     """
-    parser = argparse.ArgumentParser()
-    parser.add_argument("-m",
-                        "--model",
-                        type=str,
-                        required=True,
-                        help="Model to load")
-    parser.add_argument("-s",
-                        "--save_model",
-                        type=str,
-                        default=None,
-                        help="Save model with the specified name")
-    parser.add_argument("-laq",
-                        "--last_activ_quantization",
-                        type=int,
-                        default=None,
-                        help="The last layer activation quantization")
-    parser.add_argument("-e",
-                        "--epochs",
-                        type=int,
-                        default=0,
-                        help="The number of training epochs")
-    parser.add_argument("-b",
-                        "--batch_size",
-                        type=int,
-                        default=100,
-                        help="The training batch size")
+    parsers = get_training_parser(batch_size=100, global_batch_size=False)
 
-    sp = parser.add_subparsers(dest="action")
-    sp.add_parser("train", help="Train a Keras model")
-    sp.add_parser("eval", help="Evaluate a model")
+    train_parser = parsers[2]
+    train_parser.add_argument("-laq",
+                              "--last_activ_quantization",
+                              type=int,
+                              default=None,
+                              help="The last layer activation quantization")
 
-    args = parser.parse_args()
-
-    # Input scaling
-    # Akida is configured to take 8-bit inputs without rescaling
-    # but for the training, we use float weights between 0 and 1
-    a = 255
-    b = 0
+    args = parsers[0].parse_args()
 
     # Load the source model
     model = load_quantized_model(args.model)
 
     # If specified, change the last layer activation bitwidth
-    if args.last_activ_quantization:
+    if "last_activ_quantization" in args and args.last_activ_quantization:
         model = quantize_layer(model, 'separable_6_relu',
                                args.last_activ_quantization)
 
-    # Prepare the dataset
-    x_train, y_train, x_val, y_val = get_rescaled_dataset(a, b)
+    # Compile model
+    compile_model(model, learning_rate=2e-3)
 
-    # Training parameters
-    batch_size = args.batch_size
-    epochs = args.epochs
+    # Load data
+    x_train, y_train, x_val, y_val = get_data()
 
     # Train model
-    if epochs > 0 and args.action == "train":
-        train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs)
+    if args.action == "train":
+        train_model(model, x_train, y_train, x_val, y_val, args.batch_size,
+                    args.epochs)
 
         # Save model in Keras format (h5)
-        if args.save_model:
-            model.save(args.save_model, include_optimizer=False)
+        if args.savemodel:
+            model.save(args.savemodel, include_optimizer=False)
+            print(f"Trained model saved as {args.savemodel}")
 
-    if args.action == "eval":
+    elif args.action == "eval":
         # Evaluate model accuracy
-        evaluate_model(model, x_val, y_val)
+        evaluate_model(model, x_val, y=to_categorical(y_val))
 
 
 if __name__ == "__main__":
